pub struct Transaction<'a, DB>where
DB: Database,{ /* private fields */ }Expand description
A database transaction with auto-rollback on drop.
If the transaction is dropped without calling commit,
it will automatically roll back.
Implementations
Sourceimpl<'a> Transaction<'a, Sqlite>
impl<'a> Transaction<'a, Sqlite>
Sourcepub async fn find_by_id<E>(
&mut self,
id: <E as Entity>::Id,
) -> Result<E, FletchError>
pub async fn find_by_id<E>( &mut self, id: <E as Entity>::Id, ) -> Result<E, FletchError>
Find an entity by its primary key.
Sourcepub async fn find_all<E>(&mut self) -> Result<Vec<E>, FletchError>
pub async fn find_all<E>(&mut self) -> Result<Vec<E>, FletchError>
Fetch all entities of this type.
Sourcepub async fn insert<E>(&mut self, entity: &E) -> Result<E, FletchError>
pub async fn insert<E>(&mut self, entity: &E) -> Result<E, FletchError>
Insert a new entity and return it.
Sourcepub async fn update<E>(&mut self, entity: &E) -> Result<E, FletchError>
pub async fn update<E>(&mut self, entity: &E) -> Result<E, FletchError>
Update an existing entity and return the updated row.
Sourceimpl<'a, DB> Transaction<'a, DB>where
DB: Database,
impl<'a, DB> Transaction<'a, DB>where
DB: Database,
Sourcepub async fn commit(self) -> Result<(), FletchError>
pub async fn commit(self) -> Result<(), FletchError>
Commit the transaction.
Sourcepub async fn rollback(self) -> Result<(), FletchError>
pub async fn rollback(self) -> Result<(), FletchError>
Explicitly roll back the transaction.
Sourcepub fn inner_mut(&mut self) -> &mut Transaction<'a, DB>
pub fn inner_mut(&mut self) -> &mut Transaction<'a, DB>
Returns a mutable reference to the underlying sqlx transaction.
Escape hatch for advanced or raw SQLx access. Prefer fletch CRUD and the query builder where possible.